#!/var/folders/nz/j6p8yfhx1mv_0grj5xl4650h0000gp/T/croot-id3l3ijz/gdal-split_1643382054840/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold/bin/python
# EASY-INSTALL-SCRIPT: 'GDAL==3.0.2','gdalmove.py'
__requires__ = 'GDAL==3.0.2'
__import__('pkg_resources').run_script('GDAL==3.0.2', 'gdalmove.py')
